<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=oc_va
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Tornar a l’interfàcia grafica completa',
	'access_mode_texte' => 'Afichar l’interfàcia textuala simplificaa',
	'admin_debug' => 'desbugatge',
	'admin_modifier_article' => 'Modificar aquel article',
	'admin_modifier_auteur' => 'Modificar aquel autor',
	'admin_modifier_breve' => 'Modificar aquela brèva',
	'admin_modifier_mot' => 'Modificar aqueu mot clau',
	'admin_modifier_rubrique' => 'Modificar aquela rubrica',
	'admin_recalculer' => 'Tornar calcular la pagina',
	'alerte_maj_impossible' => '<b>Alèrta!</b> Es impossible d’actualizar la basa SQL vèrs la version @version@; bensai i a un problèma relatiu au drech de modificar la basa de donaas. Vougatz contactar vòstre auberjaor.',
	'analyse_xml' => 'Analisi XML',
	'articles_recents' => 'Los articles mai recents',
	'avis_archive_incorrect' => 'lo fichier archiu es pas un fichier SPIP',
	'avis_archive_invalide' => 'lo fichier archiu es pas valid',
	'avis_attention' => 'ATENCION!',
	'avis_champ_incorrect_type_objet' => 'Nom de champ incorrècte @name@ per objècte de tipe @type@',
	'avis_colonne_inexistante' => 'La colomna @col@ existís pas',
	'avis_erreur' => 'Error: veatz çai sos',
	'avis_erreur_connexion' => 'Error de connexion',
	'avis_erreur_cookie' => 'problèma de cookie',
	'avis_erreur_fonction_contexte' => 'Error de programacion. Chau pas apelar aquela foncion dins aqueu contèxt.',
	'avis_erreur_mysql' => 'Error SQL ',
	'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@)! ',

	// B
	'barre_a_accent_grave' => 'Inserir una A accent grèu majuscula',
	'barre_aide' => 'Utilizar las acorchas tipograficas per enrichir vòstra compaginacion',
	'barre_e_accent_aigu' => 'Inserir una E accent agut majuscula',
	'barre_eo' => 'Inserir una E dins l’O',
	'barre_eo_maj' => 'Inserir una E dins l’O majuscula',
	'barre_euro' => 'Inserir lo simbèu de l’èuro: €',
	'barre_gras' => 'Metre en {{gras}}',
	'barre_guillemets' => 'Enroar amb de « vergetas »',
	'barre_guillemets_simples' => 'Enroar amb de „vergetas“',
	'barre_intertitre' => 'Transformar en {{{intertítol}}}',
	'barre_italic' => 'Metre en {italics}',
	'barre_lien' => 'Transformar en [liam ipertèxt->http://...]',
	'barre_lien_input' => 'Vougatz indicar l’adreiça de vòstre liam (poètz indicar una adreiça web sos la forma http://www.lomieusit.com o simplament indicar lo numèro d’un article d’aqueu sit).',
	'barre_note' => 'Transformar en [[Nòta de pè]]',
	'barre_quote' => '<quote>Citar un messatge</quote>',
	'bouton_changer' => 'Chambiar',
	'bouton_chercher' => 'Cerchar',
	'bouton_choisir' => 'Chausir',
	'bouton_enregistrer' => 'Registrar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjariá intèrna',
	'bouton_radio_envoi_annonces' => 'Mandar los anoncis editoriaus',
	'bouton_radio_non_envoi_annonces' => 'Pas mandar d’anoncis',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Pas mandar la tiera de las novetats',
	'bouton_recharger_page' => 'tornar charjar aquela pagina',
	'bouton_telecharger' => 'Telecharjar',
	'bouton_upload' => 'Telecharjar', # MODIF
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'tantòst',
	'cal_jour_entier' => 'jorn entier',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'chalendier per jorn',
	'cal_par_mois' => 'chalendier per mes',
	'cal_par_semaine' => 'chalendier per setmana',
	'confirm_changer_statut' => 'Atencion, avètz demandat de chamjar l’estatut d’aquel element. Desiratz de contunhar? ',

	// D
	'date_aujourdhui' => 'encuei',
	'date_avant_jc' => 'avans lo Crist',
	'date_dans' => 'd’aquí @delai@',
	'date_de_mois_1' => '@j@ de genier',
	'date_de_mois_10' => '@j@ d’octòbre',
	'date_de_mois_11' => '@j@ de novembre',
	'date_de_mois_12' => '@j@ de decembre',
	'date_de_mois_2' => '@j@ de febrier',
	'date_de_mois_3' => '@j@ de març',
	'date_de_mois_4' => '@j@ d’abriu',
	'date_de_mois_5' => '@j@ de mai',
	'date_de_mois_6' => '@j@ de junh',
	'date_de_mois_7' => '@j@ de julh',
	'date_de_mois_8' => '@j@ d’aost',
	'date_de_mois_9' => '@j@ de setembre',
	'date_demain' => 'deman',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ a @heure@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
	'date_heures' => 'oras',
	'date_hier' => 'ièr',
	'date_il_y_a' => 'fai @delai@',
	'date_jnum1' => '1r',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimenge',
	'date_jour_2' => 'diluns',
	'date_jour_3' => 'dimars',
	'date_jour_4' => 'dimècres',
	'date_jour_5' => 'dijòus',
	'date_jour_6' => 'divendres',
	'date_jour_7' => 'dissande',
	'date_jours' => 'jorns',
	'date_minutes' => 'minutas',
	'date_mois' => 'mes(es)',
	'date_mois_1' => 'genier',
	'date_mois_10' => 'octòbre',
	'date_mois_11' => 'novembre',
	'date_mois_12' => 'decembre',
	'date_mois_2' => 'febrier',
	'date_mois_3' => 'març',
	'date_mois_4' => 'abriu',
	'date_mois_5' => 'mai',
	'date_mois_6' => 'junh',
	'date_mois_7' => 'julh',
	'date_mois_8' => 'aost',
	'date_mois_9' => 'setembre',
	'date_saison_1' => 'ivèrn',
	'date_saison_2' => 'prima',
	'date_saison_3' => 'estiu',
	'date_saison_4' => 'endarrier',
	'date_semaines' => 'setmana(s)',
	'dirs_commencer' => 'per començar verament l’installacion',
	'dirs_preliminaire' => 'Preliminar: <b>Reglar los dreches d’accès</b>',
	'dirs_probleme_droits' => 'Problèma de dreches d’accès',
	'dirs_repertoires_absents' => '<b>S’es pas trobat los repertòris seguents: <ul>@bad_dirs@.</ul> </b>
  <p>Se pòt que vena d’un problèma de majusculas o minusculas mau mesas.
  Verificatz que las minusculas e majusculas d’aqueles repertòris correspondan ben amb çò afichat
  çai sobre; s’es pas lo cas, tornatz nommar los repertòris amb vòstre logiciau FTP en corregissent l’error.
  </p><p>Un còp qu’auretz fach aquò, poiretz </p>',
	'dirs_repertoires_suivants' => '<b>Los repertòris seguents son pas accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
  <p>Per adobar aquò, utilizatz vòstre client FTP a fin de reglar los dreches d’accès de chascun
  d’aqueles repertòris. La guida d’installacion explica en detalh coma chau procedir.
  <p>Tre qu’auretz facha aquela manipulacion, poiretz ',

	// E
	'envoi_via_le_site' => 'Mandaís amb lo biais dau sit web',

	// F
	'fichier_introuvable' => 'S’es pas pogut trobar lo fichier @fichier@.', # MODIF
	'form_deja_inscrit' => 'Siatz ja inscrich(a).',
	'form_email_non_valide' => 'Vòstra adreiça e-mail es pas valida.',
	'form_forum_access_refuse' => 'Poètz pas pus accedir a aqueu sit.',
	'form_forum_bonjour' => 'Bonjorn @nom@,',
	'form_forum_email_deja_enregistre' => 'Aquela adreiça e-mail ja es registraa, adoncas poètz utilizar vòstre mot de santa Clara costumier.',
	'form_forum_identifiant_mail' => 'Vos avèm mandat vòstre identificant novèu per e-mail.',
	'form_forum_identifiants' => 'Identificants personaus',
	'form_forum_indiquer_nom_email' => 'Indicatz aquí vòstre nom e vòstra adreiça e-mail. Vòstre identificant personau arribarà lèu, per e-mail.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(aquò’s un messatge automatic)',
	'form_forum_pass' => 'mot de santa Clara:',
	'form_forum_probleme_mail' => 'Problèma d’e-mail: se pòt pas mandar l’identificant.',
	'form_forum_voici1' => 'Vaicí vòstres identificants per poer participar als forums
dau sit "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Vaicí vòstres identificants per prepausar d’articles 
 sobre lo sit "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Vougatz indicar vòstra adreiça e-mail.',
	'form_indiquer_nom' => 'Vougatz indicar vòstre nom.',
	'form_indiquer_nom_site' => 'Vougatz indicar lo nom de vòstre sit.',
	'form_pet_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_signature_pasprise' => 'Vòstra signatura es pas presa en còmpte.',
	'form_prop_confirmer_envoi' => 'Confirmar l’enviament',
	'form_prop_description' => 'Descripcion/comentari',
	'form_prop_enregistre' => 'Vòstra proposicion es ben registraa, apareisserà en linha tre que los responsables dau sit l’auràn validaa .', # MODIF
	'form_prop_envoyer' => 'Mandar un messatge',
	'form_prop_indiquer_email' => 'Vougatz indicar una adreiça e-mail valida',
	'form_prop_indiquer_nom_site' => 'Vougatz indicar lo nom dau sit.',
	'form_prop_indiquer_sujet' => 'Vougatz indicar un subjècte',
	'form_prop_message_envoye' => 'Messatge mandat',
	'form_prop_non_enregistre' => 'Vòstra proposicion es pas estaa registraa.',
	'form_prop_sujet' => 'Subjècte',
	'form_prop_url_site' => 'Adreiça (URL) dau sit', # MODIF
	'forum_non_inscrit' => 'Siá siatz pas inscrich(a), siá avètz fach una error d’adreiça o de mot de santa Clara. ',
	'forum_par_auteur' => 'per @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'Lo fichier "backend" dels articles d’aquest sit se tròba a l’adreiça:',
	'ical_texte_rss_articles2' => 'Atanben poètz obtenir de fichiers "backend" per los articles de chasca rubrica dau sit:',
	'ical_texte_rss_breves' => 'Existisson mai d’un fichier contenent las brèvas dau sit. En precisant un numèro de rubrica,  obtendretz mas que las brèvas de la rubrica aquela.',
	'icone_a_suivre' => 'De seguir',
	'icone_admin_site' => 'Administracion dau sit',
	'icone_agenda' => 'Agenda e messatjariá',
	'icone_aide_ligne' => 'Ajua',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Autors',
	'icone_brouteur' => 'Navigacion rapida',
	'icone_configuration_site' => 'Configuracion',
	'icone_configurer_site' => 'Configurar vòstre sit',
	'icone_creer_nouvel_auteur' => 'Crear un autor nòu',
	'icone_creer_rubrique' => 'Crear una rubrica',
	'icone_creer_sous_rubrique' => 'Crear una sosrubrica',
	'icone_deconnecter' => 'Se desconnectar',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents de las rubricas',
	'icone_ecrire_article' => 'Escriure un article nòu',
	'icone_edition_site' => 'Edicion',
	'icone_gestion_langues' => 'Gestion de las lengas',
	'icone_informations_personnelles' => 'Informacions personalas',
	'icone_interface_complet' => 'Interfàcia completa',
	'icone_interface_simple' => 'Interfàcia simplificaa',
	'icone_maintenance_site' => 'Mantenença dau sit',
	'icone_messagerie_personnelle' => 'Messatjariá personala',
	'icone_repartition_debut' => 'Afichar la reparticion dempuei lo començament',
	'icone_rubriques' => 'Rubricas',
	'icone_sauver_site' => 'Sauvagarda dau sit',
	'icone_site_entier' => 'Tot lo sit ',
	'icone_sites_references' => 'Sits referenciats',
	'icone_statistiques' => 'Estadisticas dau sit',
	'icone_suivi_activite' => 'Seguir l’activitat editoriala',
	'icone_suivi_actualite' => 'Evolucion dau sit',
	'icone_suivi_pettions' => 'Seguir/gerir las peticions',
	'icone_suivi_revisions' => 'Modificacions dels articles',
	'icone_supprimer_document' => 'Suprimir aqueu document',
	'icone_supprimer_image' => 'Suprimir aquel imatge',
	'icone_tous_articles' => 'Tots vòstres articles ',
	'icone_tous_auteur' => 'Tots los autors ',
	'icone_visiter_site' => 'Vesitar', # MODIF
	'icone_voir_en_ligne' => 'Veire en linha',
	'img_indisponible' => 'imatge indisponible',
	'info_a_suivre' => 'DE SEGUIR>>',
	'info_acces_interdit' => 'Accès proïbit',
	'info_acces_refuse' => 'Accès refusat',
	'info_action' => 'Accion: @action@',
	'info_administrer_rubriques' => 'Poètz administrar aquela rubrica e sas sosrubricas',
	'info_adresse_non_indiquee' => 'Avètz pas indicat l’adreiça de testar!',
	'info_aide' => 'AJUA:',
	'info_ajouter_mot' => 'Apondre aqueu mot',
	'info_annonce' => 'ANONCI',
	'info_annonces_generales' => 'Anoncis generaus:',
	'info_article_propose' => 'Article prepausat',
	'info_article_publie' => 'Article publicat',
	'info_article_redaction' => 'Article en cors de redaccion',
	'info_article_refuse' => 'Article refusat',
	'info_article_supprime' => 'Article suprimit',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Los articles de validar',
	'info_articles_proposes' => 'Articles prepausats',
	'info_auteurs_nombre' => 'autor(s)',
	'info_authentification_ftp' => 'autentificacion (per FTP).',
	'info_breves_2' => 'brèvas',
	'info_connexion_refusee' => 'Connexion refusaa',
	'info_contact_developpeur' => 'Vougatz contactar un desvolopaire.', # MODIF
	'info_contenance' => 'Aqueu sit conten:',
	'info_contribution' => 'Contribucions de forum', # MODIF
	'info_copyright' => '@spip@ es un logiciau liure distribuit @lien_gpl@.',
	'info_copyright_doc' => 'Per mai d’informacions, veire lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
	'info_copyright_gpl' => 'sos licéncia GPL',
	'info_cours_edition' => 'Vòstres articles en cors de redaccion', # MODIF
	'info_creer_repertoire' => 'Vougatz crear un fichier o un repertòri nommat',
	'info_creer_repertoire_2' => 'Dedins lo sosrepertòri   <b>@repertoire@</b>, puei:',
	'info_creer_vignette' => 'creacion automatica de la vinheta',
	'info_deplier' => 'Desplejar',
	'info_descriptif_nombre' => 'descriptiu(s):',
	'info_description' => 'Descripcion:',
	'info_description_2' => 'Descripcion:',
	'info_dimension' => 'Dimensions:',
	'info_ecire_message_prive' => 'Escriure un messatge privat',
	'info_email_invalide' => 'Adreiça e-mail invalida',
	'info_en_cours_validation' => 'Vòstres articles en cors de redaccion',
	'info_en_ligne' => 'Aüra en linha:',
	'info_envoyer_message_prive' => 'Mandar un messatge privat a aquel autor',
	'info_erreur_requete' => 'Error dins la requèsta',
	'info_erreur_squelette2' => 'Ges d’esqueleta <b>@fichier@</b> es disponibla...',
	'info_erreur_systeme' => 'Error sistèma (errno @errsys@)',
	'info_erreur_systeme2' => 'Lo disc dur es benlèu plen, o la basa de donaas degalhaa. <br />
<span style="color:red;">Assajatz de <a href=\'@script@\'>reparar la basa</a>, o contactatz vòstre auberjaor.</span>',
	'info_fini' => 'Aquò’s achabat!',
	'info_format_image' => 'Formats d’imatges que se pòon utilizar per crear de vinhetas: @gd_formats@.',
	'info_format_non_defini' => 'format non definit',
	'info_grand_ecran' => 'Ecran grand',
	'info_image_aide' => 'AJUA',
	'info_image_process_titre' => 'Metòde de fabricacion de las vinhetas',
	'info_impossible_lire_page' => '<b>Error!</b> Impossible de legir la pagina <tt><html>@test_proxy@</html></tt> a travèrs dau proxy <tt>',
	'info_installation_systeme_publication' => 'Installacion dau sistèma de publicacion...',
	'info_installer_documents' => 'Poètz installar automaticament tots los documents contenguts dins lo repertòri @upload@.',
	'info_installer_ftp' => 'Coma administrator, poètz installar (per FTP) de fichiers dins lo dorsier @upload@,  puei los  seleccionar directament aicí.', # MODIF
	'info_installer_images' => 'Poètz installar d’imatges als formats JPEG, GIF e PNG.',
	'info_installer_images_dossier' => 'Installar d’imatges dins lo dorsier @upload@ per los poer seleccionar aicí.',
	'info_interface_complete' => 'Interfàcia completa',
	'info_interface_simple' => 'Interfàcia simplificaa',
	'info_joindre_document_article' => 'Poètz jónher a aquel article de documents de la mena de',
	'info_joindre_document_rubrique' => 'Poètz apondre a aquela rubrica de documents de la mena de',
	'info_joindre_documents_article' => 'Poètz jónher a aquel article de documents de la mena de:',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la brèva',
	'info_la_rubrique' => 'la rubrica',
	'info_langue_principale' => 'Lenga majorala dau sit',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixèls',
	'info_les_auteurs_1' => 'per @les_auteurs@ ',
	'info_logo_format_interdit' => 'Los lògos de formats @formats@ son sols autorizats.',
	'info_logo_max_poids' => 'Los lògos an de far mens de @maxi@ (aquest fichier fai @actuel@).',
	'info_mail_fournisseur' => 'vos@fornior.com',
	'info_message_2' => 'MESSATGE',
	'info_message_supprime' => 'MESSATGE SUPRIMIT',
	'info_mise_en_ligne' => 'Data de mesa en linha:',
	'info_modification_parametres_securite' => 'modificacions dels paramètres de seguretat',
	'info_mois_courant' => 'Dins lo corrent dau mes:',
	'info_mot_cle_ajoute' => 'S’es apondut lo mot clau seguent a ',
	'info_multi_herit' => 'Lenga predefinia',
	'info_multi_langues_soulignees' => 'Las <u>lengas solinhaas</u> benefícian d’una reviraa de tots los tèxtes de l’interfàcia. Se seleccionatz aquelas lengas, fòrça elements dau sit public (datas, formularis) se reviraràn automaticament. Per las lengas non solinhaas, aqueles elements apareisseràn dins la lenga principala dau sit.', # MODIF
	'info_multilinguisme' => 'Multilingüisme',
	'info_nom_non_utilisateurs_connectes' => 'Vòstre nom apareis pas dins la tiera dels utilizaires connectats.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Vòstre nom apareis dins la tiera dels utilizaires connectats.', # MODIF
	'info_nombre_en_ligne' => 'Aüra en linha:',
	'info_non_resultat' => 'Ges de resultat per "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Utilizatz pas la messatjariá intèrna d’aqueu sit.',
	'info_nouveau_message' => 'AVÈTZ UN MESSATGE NÒU',
	'info_nouveaux_messages' => 'AVÈTZ @total_messages@ MESSATGES NÒUS',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'MEMENTO',
	'info_petit_ecran' => 'Ecran pechon',
	'info_pixels' => 'pixèls',
	'info_plusieurs_mots_trouves' => 'Mai d’un mot clau trobat per "@cherche_mot@" :',
	'info_portfolio_automatique' => 'Pòrtfòlio automatic:',
	'info_premier_resultat' => '[@debut_limit@ primiers resultats de @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primiers resultats de @total@]',
	'info_propose_1' => '[@nom_site_spip@] Prepausa: @titre@',
	'info_propose_2' => 'Article prepausat
---------------',
	'info_propose_3' => 'L’article "@titre@" es prepausat a la publicacion.',
	'info_propose_4' => 'Vos conviam a lo venir consultar e a bailar vòstre avís',
	'info_propose_5' => 'dins lo forum que li es estachat. Es disponible a l’adreiça:',
	'info_publie_01' => 'L’article "@titre@" es estat validat per @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICA: @titre@',
	'info_publie_2' => 'Article publicat
--------------',
	'info_rechercher' => 'Cerchar',
	'info_rechercher_02' => 'Cerchar:',
	'info_remplacer_vignette' => 'Remplaçar la vinheta predefinia per un lògo personalizat:',
	'info_sans_titre_2' => 'sensa títol',
	'info_selectionner_fichier' => 'Poètz seleccionar un fichier dau dorsier @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar un fichier:',
	'info_supprimer_vignette' => 'suprimir la vinheta',
	'info_symbole_bleu' => 'Lo simbèu <b>blau</b> marca un <b>memento</b>: aquò vòu dire un messatge per vòstre usatge personau.',
	'info_symbole_jaune' => 'Lo simbèu <b>jaune</b> marca un <b>anonci per tots los redactors </b>: los administrators lo pòon modificar, chasque redactor lo pòt veire.', # MODIF
	'info_symbole_vert' => 'Lo simbèu <b>verd</b> marca los <b>messatges eschambiats amb d’autres utilizaires</b> dau sit.', # MODIF
	'info_telecharger_nouveau_logo' => 'Telecharjar un lògo nòu:',
	'info_telecharger_ordinateur' => 'Telecharjar a partir de vòstre ordenaor:',
	'info_tous_resultats_enregistres' => '[tots los resultats son registrats]',
	'info_tout_afficher' => 'Afichar tot',
	'info_travaux_texte' => 'Aqueu sit es pas encara configurat. Tornatz mai tard...',
	'info_travaux_titre' => 'Sit en òbras',
	'info_trop_resultat' => 'Tròp de resultats per "@cherche_mot@"; vougatz afinar la recèrcha.',
	'info_utilisation_messagerie_interne' => 'Utilizatz la messatjariá intèrna d’aqueu sit.',
	'info_valider_lien' => 'validar aqueu liam',
	'info_verifier_image' => ', vougatz verificar que los imatges se sieian ben transferits.',
	'info_vignette_defaut' => 'Vinheta predefinia',
	'info_vignette_personnalisee' => 'Vinheta personalizaa',
	'info_visite' => 'vesita:',
	'info_vos_rendez_vous' => 'Vòstres rendètz-vos venents',
	'infos_vos_pense_bete' => 'Vòstres mementos', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Afichar mas que las icònas',
	'lien_afficher_texte_icones' => 'Afichar las icònas e lo tèxt',
	'lien_afficher_texte_seul' => 'Afichar mas que lo tèxt',
	'lien_liberer' => 'liberar',
	'lien_liberer_tous' => 'liberar aqueles articles', # MODIF
	'lien_nouvea_pense_bete' => 'MEMENTO NÒU',
	'lien_nouveau_message' => 'MESSATGE NÒU',
	'lien_nouvelle_annonce' => 'ANONCI NOVÈU',
	'lien_petitions' => 'PETICION',
	'lien_popularite' => 'popularitat: @popularite@%',
	'lien_racine_site' => 'RAIÇ DAU SIT',
	'lien_reessayer' => 'tornar assajar',
	'lien_repondre_message' => 'Respòndre a aqueu messatge',
	'lien_supprimer' => 'suprimir',
	'lien_tout_afficher' => 'Afichar tot',
	'lien_visite_site' => 'vesitar aqueu sit',
	'lien_visites' => '@visites@ vesitas',
	'lien_voir_auteur' => 'Veire aquel autor',
	'login_acces_prive' => 'accès a l’espaci privat',
	'login_autre_identifiant' => 'se connectar amb un autre identificant',
	'login_cookie_accepte' => 'Vougatz configurar vòstre navigaor per que los accèpte (aumens amb aqueu sit).',
	'login_cookie_oblige' => 'Per vos identificar d’una maniera segura sus aquest sit, vos chau acceptar los cookies.',
	'login_deconnexion_ok' => 'Siatz desconnectat/aa.',
	'login_erreur_pass' => 'Error de mot de santa Clara.',
	'login_espace_prive' => 'espaci privat',
	'login_identifiant_inconnu' => 'L’identificant «@login@» es inconeissut.',
	'login_login' => 'Login:',
	'login_login2' => 'Login (identificant de connexion au sit):', # MODIF
	'login_login_pass_incorrect' => '(Login o mot de santa Clara incorrècte.)',
	'login_motpasseoublie' => 'mot de santa Clara eissubliat?',
	'login_non_securise' => 'Atencion, aqueu formulari es pas securizat.
    Se volètz pas que vòstre mot de santa Clara siá
   interceptat sobre lo ret, vougatz activar Javascript 
   dins vòstre navigaor e',
	'login_nouvelle_tentative' => 'novèl assai',
	'login_par_ici' => 'Siatz registrat/aa... per aquí...',
	'login_pass2' => 'Mot de santa Clara:',
	'login_preferez_refuser' => '<b>Se vos plai mai de refusar los cookies</b>, un autre metòde de connexion (mens securizat) es a vòstra disposicion:',
	'login_recharger' => 'tornar charjar aquela pagina',
	'login_rester_identifie' => 'Restar identificat quauques jorns', # MODIF
	'login_retour_public' => 'Tornar au sit public',
	'login_retour_site' => 'Tornar au sit public',
	'login_retoursitepublic' => 'tornar au sit public',
	'login_sinscrire' => 's’inscriure', # MODIF
	'login_test_navigateur' => 'Assai navigaor/tornar connectar',
	'login_verifiez_navigateur' => '(pasmens verificatz que vòstre navigaor aia pas servat vòstre mot de santa Clara en memòria...)',

	// M
	'module_fichiers_langues' => 'Fichiers de lenga',

	// N
	'navigateur_pas_redirige' => 'Se vòstre navigaor es pas redirigit, clicatz aicí per contunhar.',

	// O
	'onglet_affacer_base' => 'Esfaçar la basa',
	'onglet_auteur' => 'L’autor',
	'onglet_contenu_site' => 'Contengut dau sit',
	'onglet_evolution_visite_mod' => 'Evolucion',
	'onglet_fonctions_avances' => 'Foncions avançaas',
	'onglet_informations_personnelles' => 'Informacions personalas',
	'onglet_interactivite' => 'Interactivitat',
	'onglet_messagerie' => 'Messatjariá',
	'onglet_repartition_rubrique' => 'Reparticion per rubricas',
	'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
	'onglet_vider_cache' => 'Voidar l’escondeor',

	// P
	'pass_choix_pass' => 'Vougatz chausir vòstre mot de santa Clara novèu:',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error :</b> poètz pas pus accedir a aqueu sit.',
	'pass_erreur_code_inconnu' => '<b>Error:</b> aqueu còde correspònd pas a ges de vesitaire que poissa accedir a aqueu sit.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Error:</b> l’adreiça <tt>@email_oubli@</tt> es pas registraa sus aqueu sit.',
	'pass_erreur_non_valide' => '<b>Error:</b> aquel e-mail <tt>@email_oubli@</tt> es pas valid!',
	'pass_erreur_probleme_technique' => '<b>Error:</b> per l’amor d’un problèma tecnic, l’e-mail se pòt pas mandar. ',
	'pass_espace_prive_bla' => 'L’espaci privat d’aquest sit es dubèrt als
  vesitaires que se son inscriches. Un còp registrat/aa,
  poiretz consultar los articles en cors de redaccion,
  prepausar d’articles novèus e participar a tots los forums.', # MODIF
	'pass_forum_bla' => 'Avètz demandat d’intervenir dins un forum
  reservat als vesitaires registrats.', # MODIF
	'pass_indiquez_cidessous' => 'Marcatz çai sos l’adreiça e-mail ont
 vos registrèretz lo còp passat. 
   Recebretz un e-mail que vos bailarà la maniera de 
    tornar trobar vòstre accès.',
	'pass_mail_passcookie' => '(aquò’s un messatge automatic)
Per tornar trobar vòstre accès au sit
@nom_site_spip@ (@adresse_site@)

Vougatz anar a l’adreiça seguenta:

    @sendcookie@

Alora poiretz intrar un mot de santa Clara novèu
e vos tornar connectar au sit.

', # MODIF
	'pass_mot_oublie' => 'Mot de santa Clara eissubliat',
	'pass_nouveau_enregistre' => 'Vòstre mot de santa Clara novèu es estat registrat.',
	'pass_nouveau_pass' => 'Mot de santa Clara novèu',
	'pass_ok' => 'Consent',
	'pass_oubli_mot' => 'Mot de santa Clara eissubliat',
	'pass_quitter_fenetre' => 'Quitar aquesta fenèstra ',
	'pass_rappel_login' => 'Remembrança: vòstre identificant (login) es «@login@».',
	'pass_recevoir_mail' => 'Recebretz un e-mail que vos explicarà coma tornar trobar vòstre accès au sit.', # MODIF
	'pass_retour_public' => 'Tornar au sit public',
	'pass_rien_a_faire_ici' => 'Ren a faire aicí.',
	'pass_vousinscrire' => 'S’inscriure sus aquest sit',
	'precedent' => 'precedent',
	'previsualisation' => 'Previsualizacion',
	'previsualiser' => 'Previsualizar',

	// S
	'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
	'suivant' => 'seguent',

	// T
	'taille_ko' => '@taille@ Ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octets',
	'texte_actualite_site_1' => 'Quand vos seretz familharizat/aa amb l’interfàcia, poiretz clicar sobre «',
	'texte_actualite_site_2' => 'Interfàcia completa',
	'texte_actualite_site_3' => '" per durbir mai de possibilitats.',
	'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualizacion es activaa sus aqueu sit. S’installatz a partir d’aqueu formulari d’imatges au (als) format(s) @gd_formats@, s’acompanharàn d’una vinheta d’una talha maximala de @taille_preview@ pixèls.',
	'texte_documents_associes' => 'Los documents seguents s’assòcian a l’article,
 mas s’inserisson pas
 directament. Segon la compaginacion dau sit public,
 poiràn aparéisser sos forma de documents jonches.',
	'texte_erreur_mise_niveau_base' => 'Error de basa de donaas pendent la mesa a nivèu. L’imatge <b>@fichier@</b> es pas passat (article @id_article@).
  Notatz ben aquela referéncia, tornatz assajar la mesa a
 nivèu, e verificatz puei que los imatges apareissan
 encara dins los articles.',
	'texte_inc_auth_1' => 'Siatz identificat/aa coma
   <b>@auth_login@</b>, mas aqueu login existís pas o pas pus dins la basa.
  Assajatz de vos', # MODIF
	'texte_inc_auth_2' => 'tornar connectar',
	'texte_inc_auth_3' => ', après qu’auretz quitat eventualament, puei
  tornat lançar vòstre navigaor.',
	'texte_inc_config' => 'Las modificacions fachas dins aquestas paginas influéncian ferme lo
 foncionament de vòstre sit. Vos aconselham de pas i intervenir tant que sieiatz pas
 acostumat/aa au foncionament dau sistèma SPIP. <br /><br /><b>
 En generau, se conselha fòrt
 de laissar la charja d’aquestas paginas au webmèstre principau de vòstre sit.</b>',
	'texte_inc_meta_1' => 'Lo sistèma a rescontrat una error dins l’escritura dau fichier <code>@fichier@</code>.Volhatz, coma administrator/tritz dau sit,', # MODIF
	'texte_inc_meta_2' => 'verificar los dreches d’escritura',
	'texte_inc_meta_3' => 'dins lo repertòri <code>@repertoire@<code>.',
	'texte_statut_en_cours_redaction' => 'en cors de redaccion',
	'texte_statut_poubelle' => 'au bordilhier',
	'texte_statut_propose_evaluation' => 'prepausat per avaloracion',
	'texte_statut_publie' => 'publicat en linha',
	'texte_statut_refuse' => 'refusat',
	'titre_ajouter_mot_cle' => 'APONDRE UN MOT CLAU:',
	'titre_cadre_raccourcis' => 'ACORCHAS:',
	'titre_changer_couleur_interface' => 'Chambiar la color de l’interfàcia',
	'titre_image_admin_article' => 'Poètz administrar aquest article',
	'titre_image_administrateur' => 'Administrator', # MODIF
	'titre_image_aide' => 'D’ajua sobre aquel element',
	'titre_image_auteur_supprime' => 'Autor suprimit',
	'titre_image_redacteur' => 'Redactor sens accès',
	'titre_image_redacteur_02' => 'Redactor',
	'titre_image_visiteur' => 'Vesitaire',
	'titre_joindre_document' => 'JÓNHER UN DOCUMENT',
	'titre_mots_cles' => 'MOTS CLAU',
	'titre_probleme_technique' => 'Atencion: un problèma tecnic (servior SQL) empacha d’accedir a aquela part dau sit. Mercé de vòstra indulgéncia.',
	'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
	'titre_statistiques' => 'Estadisticas dau sit',
	'titre_titre_document' => 'Títol dau document:',
	'trad_reference' => '(article de referéncia)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : balisa B en avau',
	'zbug_boucle' => 'bloca',
	'zbug_boucle_recursive_undef' => 'bloca recursiva non definia', # MODIF
	'zbug_champ_hors_boucle' => 'Champ @champ@ fòra bloca',
	'zbug_champ_hors_motif' => 'Champ @champ@ en defòra d’una blocla de motiu @motif@', # MODIF
	'zbug_code' => 'còde',
	'zbug_critere_inconnu' => 'critèri inconegut @critere@', # MODIF
	'zbug_distant_interdit' => 'extèrne enebit', # MODIF
	'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
	'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barraor manca', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorrècta', # MODIF
	'zbug_erreur_execution_page' => 'error d’execucion de la pagina', # MODIF
	'zbug_erreur_filtre' => 'Error: filtre <b>« @filtre@ »</b> non definit', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} s’aplica mas qu’a las blocas (FORUMS) o (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Error(s) dins l’esqueleta',
	'zbug_info_erreur_squelette' => 'Error sobre lo sit',
	'zbug_inversion_ordre_inexistant' => 'inversion d’un òrdre inexistent', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Paramètres d’inclusion incorrèctes', # MODIF
	'zbug_resultat' => 'resultat',
	'zbug_serveur_indefini' => 'servior SQL indefinit', # MODIF
	'zbug_table_inconnue' => 'Taula SQL «@table@» inconegua',
];
